# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .accounts import (
    Account,
    GetAccountRequest,
    ListChildAccountsRequest,
    ListChildAccountsResponse,
    UpdateAccountLabelsRequest,
)
from .accounts_labels import (
    AccountLabel,
    CreateAccountLabelRequest,
    DeleteAccountLabelRequest,
    ListAccountLabelsRequest,
    ListAccountLabelsResponse,
    UpdateAccountLabelRequest,
)
from .css_product_common import (
    Attributes,
    Certification,
    CssProductStatus,
    HeadlineOfferInstallment,
    HeadlineOfferSubscriptionCost,
    ProductDetail,
    ProductDimension,
    ProductWeight,
    SubscriptionPeriod,
)
from .css_product_inputs import (
    CssProductInput,
    DeleteCssProductInputRequest,
    InsertCssProductInputRequest,
    UpdateCssProductInputRequest,
)
from .css_products import (
    CssProduct,
    GetCssProductRequest,
    ListCssProductsRequest,
    ListCssProductsResponse,
)

__all__ = (
    "Account",
    "GetAccountRequest",
    "ListChildAccountsRequest",
    "ListChildAccountsResponse",
    "UpdateAccountLabelsRequest",
    "AccountLabel",
    "CreateAccountLabelRequest",
    "DeleteAccountLabelRequest",
    "ListAccountLabelsRequest",
    "ListAccountLabelsResponse",
    "UpdateAccountLabelRequest",
    "Attributes",
    "Certification",
    "CssProductStatus",
    "HeadlineOfferInstallment",
    "HeadlineOfferSubscriptionCost",
    "ProductDetail",
    "ProductDimension",
    "ProductWeight",
    "SubscriptionPeriod",
    "CssProductInput",
    "DeleteCssProductInputRequest",
    "InsertCssProductInputRequest",
    "UpdateCssProductInputRequest",
    "CssProduct",
    "GetCssProductRequest",
    "ListCssProductsRequest",
    "ListCssProductsResponse",
)



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
from google.shopping.type.types import types
import proto  # type: ignore

from google.shopping.css_v1.types import css_product_common

__protobuf__ = proto.module(
    package="google.shopping.css.v1",
    manifest={
        "CssProductInput",
        "InsertCssProductInputRequest",
        "UpdateCssProductInputRequest",
        "DeleteCssProductInputRequest",
    },
)


class CssProductInput(proto.Message):
    r"""This resource represents input data you submit for a CSS
    Product, not the processed CSS Product that you see in CSS
    Center, in Shopping Ads, or across Google surfaces.

    Attributes:
        name (str):
            The name of the CSS Product input. Format:
            ``accounts/{account}/cssProductInputs/{css_product_input}``
        final_name (str):
            Output only. The name of the processed CSS Product. Format:
            ``accounts/{account}/cssProducts/{css_product}`` ".
        raw_provided_id (str):
            Required. Your unique identifier for the CSS Product. This
            is the same for the CSS Product input and processed CSS
            Product. We only allow ids with alphanumerics, underscores
            and dashes. See the `products feed
            specification <https://support.google.com/merchants/answer/188494#id>`__
            for details.
        content_language (str):
            Required. The two-letter `ISO
            639-1 <http://en.wikipedia.org/wiki/ISO_639-1>`__ language
            code for the CSS Product.
        feed_label (str):
            Required. The `feed
            label <https://developers.google.com/shopping-content/guides/products/feed-labels>`__
            for the CSS Product. Feed Label is synonymous to "target
            country" and hence should always be a valid region code. For
            example: 'DE' for Germany, 'FR' for France.
        freshness_time (google.protobuf.timestamp_pb2.Timestamp):
            DEPRECATED. Use expiration_date instead. Represents the
            existing version (freshness) of the CSS Product, which can
            be used to preserve the right order when multiple updates
            are done at the same time.

            This field must not be set to the future time.

            If set, the update is prevented if a newer version of the
            item already exists in our system (that is the last update
            time of the existing CSS products is later than the
            freshness time set in the update). If the update happens,
            the last update time is then set to this freshness time.

            If not set, the update will not be prevented and the last
            update time will default to when this request was received
            by the CSS API.

            If the operation is prevented, the aborted exception will be
            thrown.
        attributes (google.shopping.css_v1.types.Attributes):
            A list of CSS Product attributes.
        custom_attributes (MutableSequence[google.shopping.type.types.CustomAttribute]):
            A list of custom (CSS-provided) attributes. It can also be
            used for submitting any attribute of the feed specification
            in its generic form (for example:
            ``{ "name": "size type", "value": "regular" }``). This is
            useful for submitting attributes not explicitly exposed by
            the API, such as additional attributes used for Buy on
            Google.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    final_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    raw_provided_id: str = proto.Field(
        proto.STRING,
        number=3,
    )
    content_language: str = proto.Field(
        proto.STRING,
        number=4,
    )
    feed_label: str = proto.Field(
        proto.STRING,
        number=5,
    )
    freshness_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        message=timestamp_pb2.Timestamp,
    )
    attributes: css_product_common.Attributes = proto.Field(
        proto.MESSAGE,
        number=7,
        message=css_product_common.Attributes,
    )
    custom_attributes: MutableSequence[types.CustomAttribute] = proto.RepeatedField(
        proto.MESSAGE,
        number=8,
        message=types.CustomAttribute,
    )


class InsertCssProductInputRequest(proto.Message):
    r"""Request message for the InsertCssProductInput method.

    Attributes:
        parent (str):
            Required. The account where this CSS Product
            will be inserted. Format: accounts/{account}
        css_product_input (google.shopping.css_v1.types.CssProductInput):
            Required. The CSS Product Input to insert.
        feed_id (int):
            Optional. DEPRECATED. Feed id is not required
            for CSS Products. The primary or supplemental
            feed id. If CSS Product already exists and feed
            id provided is different, then the CSS Product
            will be moved to a new feed.
            Note: For now, CSSs do not need to provide feed
            ids as we create feeds on the fly.
            We do not have supplemental feed support for CSS
            Products yet.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    css_product_input: "CssProductInput" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="CssProductInput",
    )
    feed_id: int = proto.Field(
        proto.INT64,
        number=3,
    )


class UpdateCssProductInputRequest(proto.Message):
    r"""Request message for the UpdateCssProductInput method.

    Attributes:
        css_product_input (google.shopping.css_v1.types.CssProductInput):
            Required. The CSS product input resource to
            update. Information you submit will be applied
            to the processed CSS product as well.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            The list of CSS product attributes to be updated.

            If the update mask is omitted, then it is treated as implied
            field mask equivalent to all fields that are populated (have
            a non-empty value).

            Attributes specified in the update mask without a value
            specified in the body will be deleted from the CSS product.

            Update mask can only be specified for top level fields in
            attributes and custom attributes.

            To specify the update mask for custom attributes you need to
            add the ``custom_attribute.`` prefix.

            Providing special "*" value for full CSS product replacement
            is not supported.
    """

    css_product_input: "CssProductInput" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="CssProductInput",
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class DeleteCssProductInputRequest(proto.Message):
    r"""Request message for the DeleteCssProductInput method.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Required. The name of the CSS product input resource to
            delete. Format:
            accounts/{account}/cssProductInputs/{css_product_input}
        supplemental_feed_id (int):
            The Content API Supplemental Feed ID.
            The field must not be set if the action applies
            to a primary feed. If the field is set, then
            product action applies to a supplemental feed
            instead of primary Content API feed.

            This field is a member of `oneof`_ ``_supplemental_feed_id``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    supplemental_feed_id: int = proto.Field(
        proto.INT64,
        number=2,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.shopping.css.v1",
    manifest={
        "AccountLabel",
        "ListAccountLabelsRequest",
        "ListAccountLabelsResponse",
        "CreateAccountLabelRequest",
        "UpdateAccountLabelRequest",
        "DeleteAccountLabelRequest",
    },
)


class AccountLabel(proto.Message):
    r"""Label assigned by CSS domain or CSS group to one of its
    sub-accounts.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            The resource name of the label.
            Format: accounts/{account}/labels/{label}
        label_id (int):
            Output only. The ID of the label.
        account_id (int):
            Output only. The ID of account this label
            belongs to.
        display_name (str):
            The display name of this label.

            This field is a member of `oneof`_ ``_display_name``.
        description (str):
            The description of this label.

            This field is a member of `oneof`_ ``_description``.
        label_type (google.shopping.css_v1.types.AccountLabel.LabelType):
            Output only. The type of this label.
    """

    class LabelType(proto.Enum):
        r"""The label type.

        Values:
            LABEL_TYPE_UNSPECIFIED (0):
                Unknown label type.
            MANUAL (1):
                Indicates that the label was created
                manually.
            AUTOMATIC (2):
                Indicates that the label was created
                automatically by CSS Center.
        """
        LABEL_TYPE_UNSPECIFIED = 0
        MANUAL = 1
        AUTOMATIC = 2

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    label_id: int = proto.Field(
        proto.INT64,
        number=2,
    )
    account_id: int = proto.Field(
        proto.INT64,
        number=3,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    description: str = proto.Field(
        proto.STRING,
        number=5,
        optional=True,
    )
    label_type: LabelType = proto.Field(
        proto.ENUM,
        number=6,
        enum=LabelType,
    )


class ListAccountLabelsRequest(proto.Message):
    r"""Request message for the ``ListAccountLabels`` method.

    Attributes:
        parent (str):
            Required. The parent account.
            Format: accounts/{account}
        page_size (int):
            The maximum number of labels to return. The
            service may return fewer than this value.
            If unspecified, at most 50 labels will be
            returned. The maximum value is 1000; values
            above 1000 will be coerced to 1000.
        page_token (str):
            A page token, received from a previous ``ListAccountLabels``
            call. Provide this to retrieve the subsequent page.

            When paginating, all other parameters provided to
            ``ListAccountLabels`` must match the call that provided the
            page token.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListAccountLabelsResponse(proto.Message):
    r"""Response message for the ``ListAccountLabels`` method.

    Attributes:
        account_labels (MutableSequence[google.shopping.css_v1.types.AccountLabel]):
            The labels from the specified account.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    account_labels: MutableSequence["AccountLabel"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="AccountLabel",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class CreateAccountLabelRequest(proto.Message):
    r"""Request message for the 'CreateAccountLanel' method.

    Attributes:
        parent (str):
            Required. The parent account.
            Format: accounts/{account}
        account_label (google.shopping.css_v1.types.AccountLabel):
            Required. The label to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    account_label: "AccountLabel" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="AccountLabel",
    )


class UpdateAccountLabelRequest(proto.Message):
    r"""Request message for the ``UpdateAccountLabel`` method.

    Attributes:
        account_label (google.shopping.css_v1.types.AccountLabel):
            Required. The updated label. All fields must
            be provided.
    """

    account_label: "AccountLabel" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="AccountLabel",
    )


class DeleteAccountLabelRequest(proto.Message):
    r"""Request message for the 'DeleteAccountLabel' method.

    Attributes:
        name (str):
            Required. The name of the label to delete.
            Format:  accounts/{account}/labels/{label}
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.shopping.css.v1",
    manifest={
        "ListChildAccountsRequest",
        "ListChildAccountsResponse",
        "GetAccountRequest",
        "UpdateAccountLabelsRequest",
        "Account",
    },
)


class ListChildAccountsRequest(proto.Message):
    r"""The request message for the ``ListChildAccounts`` method.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        parent (str):
            Required. The parent account. Must be a CSS
            group or domain. Format: accounts/{account}
        label_id (int):
            If set, only the MC accounts with the given
            label ID will be returned.

            This field is a member of `oneof`_ ``_label_id``.
        full_name (str):
            If set, only the MC accounts with the given
            name (case sensitive) will be returned.

            This field is a member of `oneof`_ ``_full_name``.
        page_size (int):
            Optional. The maximum number of accounts to
            return. The service may return fewer than this
            value. If unspecified, at most 50 accounts will
            be returned. The maximum value is 100; values
            above 100 will be coerced to 100.
        page_token (str):
            Optional. A page token, received from a previous
            ``ListChildAccounts`` call. Provide this to retrieve the
            subsequent page.

            When paginating, all other parameters provided to
            ``ListChildAccounts`` must match the call that provided the
            page token.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    label_id: int = proto.Field(
        proto.INT64,
        number=2,
        optional=True,
    )
    full_name: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=4,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=5,
    )


class ListChildAccountsResponse(proto.Message):
    r"""Response message for the ``ListChildAccounts`` method.

    Attributes:
        accounts (MutableSequence[google.shopping.css_v1.types.Account]):
            The CSS/MC accounts returned for the
            specified CSS parent account.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    accounts: MutableSequence["Account"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="Account",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetAccountRequest(proto.Message):
    r"""The request message for the ``GetAccount`` method.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Required. The name of the managed CSS/MC
            account. Format: accounts/{account}
        parent (str):
            Optional. Only required when retrieving MC
            account information. The CSS domain that is the
            parent resource of the MC account. Format:
            accounts/{account}

            This field is a member of `oneof`_ ``_parent``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    parent: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class UpdateAccountLabelsRequest(proto.Message):
    r"""The request message for the ``UpdateLabels`` method.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Required. The label resource name.
            Format: accounts/{account}
        label_ids (MutableSequence[int]):
            The list of label IDs to overwrite the
            existing account label IDs. If the list is
            empty, all currently assigned label IDs will be
            deleted.
        parent (str):
            Optional. Only required when updating MC
            account labels. The CSS domain that is the
            parent resource of the MC account. Format:
            accounts/{account}

            This field is a member of `oneof`_ ``_parent``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    label_ids: MutableSequence[int] = proto.RepeatedField(
        proto.INT64,
        number=2,
    )
    parent: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )


class Account(proto.Message):
    r"""Information about CSS/MC account.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            The label resource name.
            Format: accounts/{account}
        full_name (str):
            Output only. Immutable. The CSS/MC account's
            full name.
        display_name (str):
            The CSS/MC account's short display name.

            This field is a member of `oneof`_ ``_display_name``.
        homepage_uri (str):
            Output only. Immutable. The CSS/MC account's
            homepage.

            This field is a member of `oneof`_ ``_homepage_uri``.
        parent (str):
            The CSS/MC account's parent resource. CSS
            group for CSS domains; CSS domain for MC
            accounts. Returned only if the user has access
            to the parent account.

            This field is a member of `oneof`_ ``_parent``.
        label_ids (MutableSequence[int]):
            Manually created label IDs assigned to the
            CSS/MC account by a CSS parent account.
        automatic_label_ids (MutableSequence[int]):
            Automatically created label IDs assigned to
            the MC account by CSS Center.
        account_type (google.shopping.css_v1.types.Account.AccountType):
            Output only. The type of this account.
    """

    class AccountType(proto.Enum):
        r"""The account type.

        Values:
            ACCOUNT_TYPE_UNSPECIFIED (0):
                Unknown account type.
            CSS_GROUP (1):
                CSS group account.
            CSS_DOMAIN (2):
                CSS domain account.
            MC_PRIMARY_CSS_MCA (3):
                MC Primary CSS MCA account.
            MC_CSS_MCA (4):
                MC CSS MCA account.
            MC_MARKETPLACE_MCA (5):
                MC Marketplace MCA account.
            MC_OTHER_MCA (6):
                MC Other MCA account.
            MC_STANDALONE (7):
                MC Standalone account.
            MC_MCA_SUBACCOUNT (8):
                MC MCA sub-account.
        """
        ACCOUNT_TYPE_UNSPECIFIED = 0
        CSS_GROUP = 1
        CSS_DOMAIN = 2
        MC_PRIMARY_CSS_MCA = 3
        MC_CSS_MCA = 4
        MC_MARKETPLACE_MCA = 5
        MC_OTHER_MCA = 6
        MC_STANDALONE = 7
        MC_MCA_SUBACCOUNT = 8

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    full_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    homepage_uri: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    parent: str = proto.Field(
        proto.STRING,
        number=5,
        optional=True,
    )
    label_ids: MutableSequence[int] = proto.RepeatedField(
        proto.INT64,
        number=6,
    )
    automatic_label_ids: MutableSequence[int] = proto.RepeatedField(
        proto.INT64,
        number=7,
    )
    account_type: AccountType = proto.Field(
        proto.ENUM,
        number=8,
        enum=AccountType,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
from google.shopping.type.types import types
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.shopping.css.v1",
    manifest={
        "SubscriptionPeriod",
        "Attributes",
        "Certification",
        "ProductDetail",
        "ProductDimension",
        "ProductWeight",
        "CssProductStatus",
        "HeadlineOfferSubscriptionCost",
        "HeadlineOfferInstallment",
    },
)


class SubscriptionPeriod(proto.Enum):
    r"""The subscription period of the product.

    Values:
        SUBSCRIPTION_PERIOD_UNSPECIFIED (0):
            Indicates that the subscription period is
            unspecified.
        MONTH (1):
            Indicates that the subscription period is
            month.
        YEAR (2):
            Indicates that the subscription period is
            year.
    """
    SUBSCRIPTION_PERIOD_UNSPECIFIED = 0
    MONTH = 1
    YEAR = 2


class Attributes(proto.Message):
    r"""Attributes for CSS Product.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        cpp_link (str):
            URL directly linking to your the Product
            Detail Page of the CSS.

            This field is a member of `oneof`_ ``_cpp_link``.
        cpp_mobile_link (str):
            URL for the mobile-optimized version of the
            Product Detail Page of the CSS.

            This field is a member of `oneof`_ ``_cpp_mobile_link``.
        cpp_ads_redirect (str):
            Allows advertisers to override the item URL
            when the product is shown within the context of
            Product Ads.

            This field is a member of `oneof`_ ``_cpp_ads_redirect``.
        low_price (google.shopping.type.types.Price):
            Low Price of the CSS Product.
        high_price (google.shopping.type.types.Price):
            High Price of the CSS Product.
        number_of_offers (int):
            The number of CSS Products.

            This field is a member of `oneof`_ ``_number_of_offers``.
        headline_offer_condition (str):
            Condition of the headline offer.

            This field is a member of `oneof`_ ``_headline_offer_condition``.
        headline_offer_price (google.shopping.type.types.Price):
            Headline Price of the CSS Product.
        headline_offer_link (str):
            Link to the headline offer.

            This field is a member of `oneof`_ ``_headline_offer_link``.
        headline_offer_mobile_link (str):
            Mobile Link to the headline offer.

            This field is a member of `oneof`_ ``_headline_offer_mobile_link``.
        headline_offer_shipping_price (google.shopping.type.types.Price):
            Headline Price of the CSS Product.
        title (str):
            Title of the item.

            This field is a member of `oneof`_ ``_title``.
        image_link (str):
            URL of an image of the item.

            This field is a member of `oneof`_ ``_image_link``.
        additional_image_links (MutableSequence[str]):
            Additional URL of images of the item.
        description (str):
            Description of the item.

            This field is a member of `oneof`_ ``_description``.
        brand (str):
            Product Related Attributes.[14-36] Brand of the item.

            This field is a member of `oneof`_ ``_brand``.
        mpn (str):
            Manufacturer Part Number
            (`MPN <https://support.google.com/merchants/answer/188494#mpn>`__)
            of the item.

            This field is a member of `oneof`_ ``_mpn``.
        gtin (str):
            Global Trade Item Number
            (`GTIN <https://support.google.com/merchants/answer/188494#gtin>`__)
            of the item.

            This field is a member of `oneof`_ ``_gtin``.
        product_types (MutableSequence[str]):
            Categories of the item (formatted as in `products data
            specification <https://support.google.com/merchants/answer/6324406>`__).
        google_product_category (str):
            Google's category of the item (see `Google product
            taxonomy <https://support.google.com/merchants/answer/1705911>`__).
            When querying products, this field will contain the user
            provided value. There is currently no way to get back the
            auto assigned google product categories through the API.

            This field is a member of `oneof`_ ``_google_product_category``.
        adult (bool):
            Set to true if the item is targeted towards
            adults.

            This field is a member of `oneof`_ ``_adult``.
        multipack (int):
            The number of identical products in a
            merchant-defined multipack.

            This field is a member of `oneof`_ ``_multipack``.
        is_bundle (bool):
            Whether the item is a merchant-defined
            bundle. A bundle is a custom grouping of
            different products sold by a merchant for a
            single price.

            This field is a member of `oneof`_ ``_is_bundle``.
        age_group (str):
            Target age group of the item.

            This field is a member of `oneof`_ ``_age_group``.
        color (str):
            Color of the item.

            This field is a member of `oneof`_ ``_color``.
        gender (str):
            Target gender of the item.

            This field is a member of `oneof`_ ``_gender``.
        material (str):
            The material of which the item is made.

            This field is a member of `oneof`_ ``_material``.
        pattern (str):
            The item's pattern (e.g. polka dots).

            This field is a member of `oneof`_ ``_pattern``.
        size (str):
            Size of the item. Only one value is allowed. For variants
            with different sizes, insert a separate product for each
            size with the same ``itemGroupId`` value (see
            [https://support.google.com/merchants/answer/6324492](size
            definition)).

            This field is a member of `oneof`_ ``_size``.
        size_system (str):
            System in which the size is specified.
            Recommended for apparel items.

            This field is a member of `oneof`_ ``_size_system``.
        size_types (MutableSequence[str]):
            The cut of the item. It can be used to represent combined
            size types for apparel items. Maximum two of size types can
            be provided (see
            [https://support.google.com/merchants/answer/6324497](size
            type)).
        item_group_id (str):
            Shared identifier for all variants of the
            same product.

            This field is a member of `oneof`_ ``_item_group_id``.
        product_details (MutableSequence[google.shopping.css_v1.types.ProductDetail]):
            Technical specification or additional product
            details.
        product_weight (google.shopping.css_v1.types.ProductWeight):
            The weight of the product in the units
            provided. The value must be between 0
            (exclusive) and 2000 (inclusive).
        product_length (google.shopping.css_v1.types.ProductDimension):
            The length of the product in the units
            provided. The value must be between 0
            (exclusive) and 3000 (inclusive).
        product_width (google.shopping.css_v1.types.ProductDimension):
            The width of the product in the units
            provided. The value must be between 0
            (exclusive) and 3000 (inclusive).
        product_height (google.shopping.css_v1.types.ProductDimension):
            The height of the product in the units
            provided. The value must be between
            0 (exclusive) and 3000 (inclusive).
        product_highlights (MutableSequence[str]):
            Bullet points describing the most relevant
            highlights of a product.
        certifications (MutableSequence[google.shopping.css_v1.types.Certification]):
            A list of certificates claimed by the CSS for
            the given product.
        expiration_date (google.protobuf.timestamp_pb2.Timestamp):
            Date on which the item should expire, as specified upon
            insertion, in `ISO
            8601 <http://en.wikipedia.org/wiki/ISO_8601>`__ format. The
            actual expiration date is exposed in ``productstatuses`` as
            `googleExpirationDate <https://support.google.com/merchants/answer/6324499>`__
            and might be earlier if ``expirationDate`` is too far in the
            future. Note: It may take 2+ days from the expiration date
            for the item to actually get deleted.
        included_destinations (MutableSequence[str]):
            The list of destinations to include for this target
            (corresponds to checked check boxes in Merchant Center).
            Default destinations are always included unless provided in
            ``excludedDestinations``.
        excluded_destinations (MutableSequence[str]):
            The list of destinations to exclude for this
            target (corresponds to unchecked check boxes in
            Merchant Center).
        pause (str):
            Publication of this item will be temporarily
            paused.

            This field is a member of `oneof`_ ``_pause``.
        custom_label_0 (str):
            Custom label 0 for custom grouping of items
            in a Shopping campaign.

            This field is a member of `oneof`_ ``_custom_label_0``.
        custom_label_1 (str):
            Custom label 1 for custom grouping of items
            in a Shopping campaign.

            This field is a member of `oneof`_ ``_custom_label_1``.
        custom_label_2 (str):
            Custom label 2 for custom grouping of items
            in a Shopping campaign.

            This field is a member of `oneof`_ ``_custom_label_2``.
        custom_label_3 (str):
            Custom label 3 for custom grouping of items
            in a Shopping campaign.

            This field is a member of `oneof`_ ``_custom_label_3``.
        custom_label_4 (str):
            Custom label 4 for custom grouping of items
            in a Shopping campaign.

            This field is a member of `oneof`_ ``_custom_label_4``.
        headline_offer_installment (google.shopping.css_v1.types.HeadlineOfferInstallment):
            Number and amount of installments to pay for
            an item.
        headline_offer_subscription_cost (google.shopping.css_v1.types.HeadlineOfferSubscriptionCost):
            Number of periods (months or years) and
            amount of payment per period for an item with an
            associated subscription contract.
    """

    cpp_link: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )
    cpp_mobile_link: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )
    cpp_ads_redirect: str = proto.Field(
        proto.STRING,
        number=42,
        optional=True,
    )
    low_price: types.Price = proto.Field(
        proto.MESSAGE,
        number=3,
        message=types.Price,
    )
    high_price: types.Price = proto.Field(
        proto.MESSAGE,
        number=4,
        message=types.Price,
    )
    number_of_offers: int = proto.Field(
        proto.INT64,
        number=5,
        optional=True,
    )
    headline_offer_condition: str = proto.Field(
        proto.STRING,
        number=6,
        optional=True,
    )
    headline_offer_price: types.Price = proto.Field(
        proto.MESSAGE,
        number=7,
        message=types.Price,
    )
    headline_offer_link: str = proto.Field(
        proto.STRING,
        number=8,
        optional=True,
    )
    headline_offer_mobile_link: str = proto.Field(
        proto.STRING,
        number=9,
        optional=True,
    )
    headline_offer_shipping_price: types.Price = proto.Field(
        proto.MESSAGE,
        number=41,
        message=types.Price,
    )
    title: str = proto.Field(
        proto.STRING,
        number=10,
        optional=True,
    )
    image_link: str = proto.Field(
        proto.STRING,
        number=11,
        optional=True,
    )
    additional_image_links: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=12,
    )
    description: str = proto.Field(
        proto.STRING,
        number=13,
        optional=True,
    )
    brand: str = proto.Field(
        proto.STRING,
        number=14,
        optional=True,
    )
    mpn: str = proto.Field(
        proto.STRING,
        number=15,
        optional=True,
    )
    gtin: str = proto.Field(
        proto.STRING,
        number=16,
        optional=True,
    )
    product_types: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=36,
    )
    google_product_category: str = proto.Field(
        proto.STRING,
        number=17,
        optional=True,
    )
    adult: bool = proto.Field(
        proto.BOOL,
        number=18,
        optional=True,
    )
    multipack: int = proto.Field(
        proto.INT64,
        number=19,
        optional=True,
    )
    is_bundle: bool = proto.Field(
        proto.BOOL,
        number=20,
        optional=True,
    )
    age_group: str = proto.Field(
        proto.STRING,
        number=21,
        optional=True,
    )
    color: str = proto.Field(
        proto.STRING,
        number=22,
        optional=True,
    )
    gender: str = proto.Field(
        proto.STRING,
        number=23,
        optional=True,
    )
    material: str = proto.Field(
        proto.STRING,
        number=24,
        optional=True,
    )
    pattern: str = proto.Field(
        proto.STRING,
        number=25,
        optional=True,
    )
    size: str = proto.Field(
        proto.STRING,
        number=26,
        optional=True,
    )
    size_system: str = proto.Field(
        proto.STRING,
        number=27,
        optional=True,
    )
    size_types: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=28,
    )
    item_group_id: str = proto.Field(
        proto.STRING,
        number=29,
        optional=True,
    )
    product_details: MutableSequence["ProductDetail"] = proto.RepeatedField(
        proto.MESSAGE,
        number=30,
        message="ProductDetail",
    )
    product_weight: "ProductWeight" = proto.Field(
        proto.MESSAGE,
        number=31,
        message="ProductWeight",
    )
    product_length: "ProductDimension" = proto.Field(
        proto.MESSAGE,
        number=32,
        message="ProductDimension",
    )
    product_width: "ProductDimension" = proto.Field(
        proto.MESSAGE,
        number=33,
        message="ProductDimension",
    )
    product_height: "ProductDimension" = proto.Field(
        proto.MESSAGE,
        number=34,
        message="ProductDimension",
    )
    product_highlights: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=35,
    )
    certifications: MutableSequence["Certification"] = proto.RepeatedField(
        proto.MESSAGE,
        number=39,
        message="Certification",
    )
    expiration_date: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=40,
        message=timestamp_pb2.Timestamp,
    )
    included_destinations: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=43,
    )
    excluded_destinations: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=44,
    )
    pause: str = proto.Field(
        proto.STRING,
        number=45,
        optional=True,
    )
    custom_label_0: str = proto.Field(
        proto.STRING,
        number=46,
        optional=True,
    )
    custom_label_1: str = proto.Field(
        proto.STRING,
        number=47,
        optional=True,
    )
    custom_label_2: str = proto.Field(
        proto.STRING,
        number=48,
        optional=True,
    )
    custom_label_3: str = proto.Field(
        proto.STRING,
        number=49,
        optional=True,
    )
    custom_label_4: str = proto.Field(
        proto.STRING,
        number=50,
        optional=True,
    )
    headline_offer_installment: "HeadlineOfferInstallment" = proto.Field(
        proto.MESSAGE,
        number=51,
        message="HeadlineOfferInstallment",
    )
    headline_offer_subscription_cost: "HeadlineOfferSubscriptionCost" = proto.Field(
        proto.MESSAGE,
        number=52,
        message="HeadlineOfferSubscriptionCost",
    )


class Certification(proto.Message):
    r"""The certification for the product. Use the this attribute to
    describe certifications, such as energy efficiency ratings,
    associated with a product.

    Attributes:
        name (str):
            The name of the certification. At this time,
            the most common value is "EPREL", which
            represents energy efficiency certifications in
            the EU European Registry for Energy Labeling
            (EPREL) database.
        authority (str):
            The authority or certification body responsible for issuing
            the certification. At this time, the most common value is
            "EC" or “European_Commission” for energy labels in the EU.
        code (str):
            The code of the certification. For example,
            for the EPREL certificate with the link
            https://eprel.ec.europa.eu/screen/product/dishwashers2019/123456
            the code is 123456. The code is required for
            European Energy Labels.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    authority: str = proto.Field(
        proto.STRING,
        number=2,
    )
    code: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ProductDetail(proto.Message):
    r"""The product details.

    Attributes:
        section_name (str):
            The section header used to group a set of
            product details.
        attribute_name (str):
            The name of the product detail.
        attribute_value (str):
            The value of the product detail.
    """

    section_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    attribute_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    attribute_value: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ProductDimension(proto.Message):
    r"""The dimension of the product.

    Attributes:
        value (float):
            Required. The dimension value represented as
            a number. The value can have a maximum precision
            of four decimal places.
        unit (str):
            Required. The dimension units. Acceptable values are:

            -  "``in``"
            -  "``cm``".
    """

    value: float = proto.Field(
        proto.DOUBLE,
        number=1,
    )
    unit: str = proto.Field(
        proto.STRING,
        number=2,
    )


class ProductWeight(proto.Message):
    r"""The weight of the product.

    Attributes:
        value (float):
            Required. The weight represented as a number.
            The weight can have a maximum precision of four
            decimal places.
        unit (str):
            Required. The weight unit. Acceptable values are:

            -  "``g``"
            -  "``kg``"
            -  "``oz``"
            -  "``lb``".
    """

    value: float = proto.Field(
        proto.DOUBLE,
        number=1,
    )
    unit: str = proto.Field(
        proto.STRING,
        number=2,
    )


class CssProductStatus(proto.Message):
    r"""The status of the Css Product, data validation issues, that
    is, information about the Css Product computed asynchronously.

    Attributes:
        destination_statuses (MutableSequence[google.shopping.css_v1.types.CssProductStatus.DestinationStatus]):
            The intended destinations for the product.
        item_level_issues (MutableSequence[google.shopping.css_v1.types.CssProductStatus.ItemLevelIssue]):
            A list of all issues associated with the
            product.
        creation_date (google.protobuf.timestamp_pb2.Timestamp):
            Date on which the item has been created, in `ISO
            8601 <http://en.wikipedia.org/wiki/ISO_8601>`__ format.
        last_update_date (google.protobuf.timestamp_pb2.Timestamp):
            Date on which the item has been last updated, in `ISO
            8601 <http://en.wikipedia.org/wiki/ISO_8601>`__ format.
        google_expiration_date (google.protobuf.timestamp_pb2.Timestamp):
            Date on which the item expires, in `ISO
            8601 <http://en.wikipedia.org/wiki/ISO_8601>`__ format.
    """

    class DestinationStatus(proto.Message):
        r"""The destination status of the product status.

        Attributes:
            destination (str):
                The name of the destination
            approved_countries (MutableSequence[str]):
                List of country codes (ISO 3166-1 alpha-2)
                where the CSS Product is approved.
            pending_countries (MutableSequence[str]):
                List of country codes (ISO 3166-1 alpha-2)
                where the CSS Product is pending approval.
            disapproved_countries (MutableSequence[str]):
                List of country codes (ISO 3166-1 alpha-2)
                where the CSS Product is disapproved.
        """

        destination: str = proto.Field(
            proto.STRING,
            number=1,
        )
        approved_countries: MutableSequence[str] = proto.RepeatedField(
            proto.STRING,
            number=2,
        )
        pending_countries: MutableSequence[str] = proto.RepeatedField(
            proto.STRING,
            number=3,
        )
        disapproved_countries: MutableSequence[str] = proto.RepeatedField(
            proto.STRING,
            number=4,
        )

    class ItemLevelIssue(proto.Message):
        r"""The ItemLevelIssue of the product status.

        Attributes:
            code (str):
                The error code of the issue.
            servability (str):
                How this issue affects serving of the CSS
                Product.
            resolution (str):
                Whether the issue can be resolved by the
                merchant.
            attribute (str):
                The attribute's name, if the issue is caused
                by a single attribute.
            destination (str):
                The destination the issue applies to.
            description (str):
                A short issue description in English.
            detail (str):
                A detailed issue description in English.
            documentation (str):
                The URL of a web page to help with resolving
                this issue.
            applicable_countries (MutableSequence[str]):
                List of country codes (ISO 3166-1 alpha-2)
                where issue applies to the CSS Product.
        """

        code: str = proto.Field(
            proto.STRING,
            number=1,
        )
        servability: str = proto.Field(
            proto.STRING,
            number=2,
        )
        resolution: str = proto.Field(
            proto.STRING,
            number=3,
        )
        attribute: str = proto.Field(
            proto.STRING,
            number=4,
        )
        destination: str = proto.Field(
            proto.STRING,
            number=5,
        )
        description: str = proto.Field(
            proto.STRING,
            number=6,
        )
        detail: str = proto.Field(
            proto.STRING,
            number=7,
        )
        documentation: str = proto.Field(
            proto.STRING,
            number=8,
        )
        applicable_countries: MutableSequence[str] = proto.RepeatedField(
            proto.STRING,
            number=9,
        )

    destination_statuses: MutableSequence[DestinationStatus] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=DestinationStatus,
    )
    item_level_issues: MutableSequence[ItemLevelIssue] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message=ItemLevelIssue,
    )
    creation_date: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=5,
        message=timestamp_pb2.Timestamp,
    )
    last_update_date: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        message=timestamp_pb2.Timestamp,
    )
    google_expiration_date: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=7,
        message=timestamp_pb2.Timestamp,
    )


class HeadlineOfferSubscriptionCost(proto.Message):
    r"""The SubscriptionCost of the product.

    Attributes:
        period (google.shopping.css_v1.types.SubscriptionPeriod):
            The type of subscription period. Supported values are:

            -  "``month``"
            -  "``year``".
        period_length (int):
            The number of subscription periods the buyer
            has to pay.
        amount (google.shopping.type.types.Price):
            The amount the buyer has to pay per
            subscription period.
    """

    period: "SubscriptionPeriod" = proto.Field(
        proto.ENUM,
        number=1,
        enum="SubscriptionPeriod",
    )
    period_length: int = proto.Field(
        proto.INT64,
        number=2,
    )
    amount: types.Price = proto.Field(
        proto.MESSAGE,
        number=3,
        message=types.Price,
    )


class HeadlineOfferInstallment(proto.Message):
    r"""A message that represents installment.

    Attributes:
        months (int):
            The number of installments the buyer has to
            pay.
        amount (google.shopping.type.types.Price):
            The amount the buyer has to pay per month.
        downpayment (google.shopping.type.types.Price):
            The up-front down payment amount the buyer
            has to pay.
    """

    months: int = proto.Field(
        proto.INT64,
        number=1,
    )
    amount: types.Price = proto.Field(
        proto.MESSAGE,
        number=2,
        message=types.Price,
    )
    downpayment: types.Price = proto.Field(
        proto.MESSAGE,
        number=3,
        message=types.Price,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.shopping.type.types import types
import proto  # type: ignore

from google.shopping.css_v1.types import css_product_common

__protobuf__ = proto.module(
    package="google.shopping.css.v1",
    manifest={
        "GetCssProductRequest",
        "CssProduct",
        "ListCssProductsRequest",
        "ListCssProductsResponse",
    },
)


class GetCssProductRequest(proto.Message):
    r"""The request message for the ``GetCssProduct`` method.

    Attributes:
        name (str):
            Required. The name of the CSS product to
            retrieve.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class CssProduct(proto.Message):
    r"""The processed CSS Product.

    Attributes:
        name (str):
            The name of the CSS Product. Format:
            ``"accounts/{account}/cssProducts/{css_product}"``
        raw_provided_id (str):
            Output only. Your unique raw identifier for
            the product.
        content_language (str):
            Output only. The two-letter `ISO
            639-1 <http://en.wikipedia.org/wiki/ISO_639-1>`__ language
            code for the product.
        feed_label (str):
            Output only. The feed label for the product.
        attributes (google.shopping.css_v1.types.Attributes):
            Output only. A list of product attributes.
        custom_attributes (MutableSequence[google.shopping.type.types.CustomAttribute]):
            Output only. A list of custom (CSS-provided) attributes. It
            can also be used to submit any attribute of the feed
            specification in its generic form (for example,
            ``{ "name": "size type", "value": "regular" }``). This is
            useful for submitting attributes not explicitly exposed by
            the API, such as additional attributes used for Buy on
            Google.
        css_product_status (google.shopping.css_v1.types.CssProductStatus):
            Output only. The status of a product, data
            validation issues, that is, information about a
            product computed asynchronously.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    raw_provided_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    content_language: str = proto.Field(
        proto.STRING,
        number=3,
    )
    feed_label: str = proto.Field(
        proto.STRING,
        number=4,
    )
    attributes: css_product_common.Attributes = proto.Field(
        proto.MESSAGE,
        number=5,
        message=css_product_common.Attributes,
    )
    custom_attributes: MutableSequence[types.CustomAttribute] = proto.RepeatedField(
        proto.MESSAGE,
        number=6,
        message=types.CustomAttribute,
    )
    css_product_status: css_product_common.CssProductStatus = proto.Field(
        proto.MESSAGE,
        number=8,
        message=css_product_common.CssProductStatus,
    )


class ListCssProductsRequest(proto.Message):
    r"""Request message for the ListCssProducts method.

    Attributes:
        parent (str):
            Required. The account/domain to list
            processed CSS Products for. Format:
            accounts/{account}
        page_size (int):
            The maximum number of CSS Products to return.
            The service may return fewer than this value.
            The maximum value is 1000; values above 1000
            will be coerced to 1000. If unspecified, the
            maximum number of CSS products will be returned.
        page_token (str):
            A page token, received from a previous ``ListCssProducts``
            call. Provide this to retrieve the subsequent page.

            When paginating, all other parameters provided to
            ``ListCssProducts`` must match the call that provided the
            page token.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListCssProductsResponse(proto.Message):
    r"""Response message for the ListCssProducts method.

    Attributes:
        css_products (MutableSequence[google.shopping.css_v1.types.CssProduct]):
            The processed CSS products from the specified
            account. These are your processed CSS products
            after applying rules and supplemental feeds.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
    """

    @property
    def raw_page(self):
        return self

    css_products: MutableSequence["CssProduct"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="CssProduct",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
